@@ -21,8 +21,9 @@ echo y | dh_make --createorig --single -e yuvraaj@gmail.com -c lgpl
 cp build-files/libmosquittopp.control debian/control
 cp build-files/libmosquittopp.rules debian/rules
 cp build-files/libmosquittopp.install debian/
+
 dpkg-buildpackage -rfakeroot -sa -S
-dput -f $1-extras-builder ./libmosquittopp*.changes
+dput -f $1-extras-builder ../libmosquittopp*.changes
 #dpkg-buildpackage -rfakeroot
 
 popd
